aboutsummaryrefslogtreecommitdiffstats
path: root/include/osmocom/bsc/gsm_data.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/osmocom/bsc/gsm_data.h')
-rw-r--r--include/osmocom/bsc/gsm_data.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/include/osmocom/bsc/gsm_data.h b/include/osmocom/bsc/gsm_data.h
index 0928d0262..c966e0506 100644
--- a/include/osmocom/bsc/gsm_data.h
+++ b/include/osmocom/bsc/gsm_data.h
@@ -142,7 +142,8 @@ struct gsm_subscriber_connection {
struct gsm_lchan *secondary_lchan;
struct llist_head assignment_queue;
- /* penalty timers for handover */
+ /* failure count and penalty timers for handover */
+ int ho_failure;
struct llist_head ho_penalty_timers;
/* phone's bearer capabilities */